@@ -27,6 +27,7 @@ class GeometryController:
         self.__meshTags = None
         self.__boundaryTags = None
         self.__physicalGroups = None
+        self.__physicalGroups1D = None
         
 
         self.__connection_nodeAndCoords = None
@@ -35,6 +36,7 @@ class GeometryController:
         #endregion entire object - attributes
 
         #region object by physical group - attributes
+        self.__connection_physicalGroup1dAndNodes = None
         self.__connection_physicalGroupAndNodes = None
         self.__connection_physicalGroupAndNormals = None
         #endregion object by physical group - attributes
@@ -88,9 +90,26 @@ class GeometryController:
         #endregion entire object - method
 
         #region object by physical group - method
+
+        # 1D
+        physicalGroups1D = []
+        connection_physicalGroup1dAndNodes = {}
+        gt1 = gmsh.model.getPhysicalGroups(1)
+        for tag in gt1:
+            physicalGroupName = gmsh.model.getPhysicalName(tag[0], tag[1])
+            physicalGroups1D.append(physicalGroupName)
+            nodes4PhysicalGroup, _ = gmsh.model.mesh.getNodesForPhysicalGroup(tag[0], tag[1])
+            connection_physicalGroup1dAndNodes[physicalGroupName] = nodes4PhysicalGroup
+        
+        self.__physicalGroups1D = physicalGroups1D
+        self.__connection_physicalGroup1dAndNodes = connection_physicalGroup1dAndNodes
+
+        # 2D and 3D
         physicalGroups = []
         connection_physicalGroupAndNodes = {}
         connection_physicalGroupAndNormals = {}
+        
+        
         gt2 = gmsh.model.getPhysicalGroups(2)
         # print(gt2)
         # print(gmsh.model.getEntities(2))
@@ -284,6 +303,31 @@ class GeometryController:
         return self.__connection_meshAndNodes[meshTag]
 
     
+    def getConnectionBetweenPhysicalGroup1dAndNodes(self, physicalGroupName=None, sort=False):
+        #region doc. string
+        """TODO: 리스트의 처음 두개의 값을 시작점과 끝점으로 간주. 체크해보니 일단은 맞는데, 앞으로 어떨지는 모르겠음.
+
+        - [Description]
+        - [Description]
+
+        Parameters
+            - [param1] - :class:`[type]`. [Description].
+            - [param2] - :class:`[type]`. [Description].
+        
+        Returns
+            - R1 ([value]) - :class:`[type]`. [Description]
+            - R2 ([value]) - :class:`[type]`. [Description]
+        """
+        #endregion doc. string
+        if (physicalGroupName==None):
+            return self.__connection_physicalGroup1dAndNodes
+        else:
+            if (physicalGroupName in self.__connection_physicalGroup1dAndNodes):
+                if (sort):
+                    return sorted(self.__connection_physicalGroup1dAndNodes[physicalGroupName])
+                return self.__connection_physicalGroup1dAndNodes[physicalGroupName]
+            print("************* error *************\n" + "There's no physical name '" + physicalGroupName + "' in the model.\n" + "*********************************\n")
+
     def getConnectionBetweenPhysicalGroupAndNodes(self, physicalGroupName=None, sort=False):
         #region doc. string
         """Function to get a connection between physical group (2-, 3-dimension) and node tags.
@@ -338,6 +382,9 @@ class GeometryController:
                 return self.__connection_physicalGroupAndNodes[physicalGroupName]
             print("************* error *************\n" + "There's no physical name '" + physicalGroupName + "' in the model.\n" + "*********************************\n")
     
+    def getPhysicalGroups1D(self):
+        #region doc. string
+        return self.__physicalGroups1D
 
     def getPhysicalGroups(self):
         #region doc. string
